@@ -60,13 +60,13 @@ NameFilterWidget::NameFilterWidget(SortedDirModel* model)
 
     mLineEdit = new QLineEdit;
 
-    QHBoxLayout* layout = new QHBoxLayout(this);
+    auto* layout = new QHBoxLayout(this);
     layout->setContentsMargins(0, 0, 0, 0);
     layout->setSpacing(2);
     layout->addWidget(mModeComboBox);
     layout->addWidget(mLineEdit);
 
-    QTimer* timer = new QTimer(this);
+    auto* timer = new QTimer(this);
     timer->setInterval(350);
     timer->setSingleShot(true);
     connect(timer, &QTimer::timeout, this, &NameFilterWidget::applyNameFilter);
@@ -103,7 +103,7 @@ DateFilterWidget::DateFilterWidget(SortedDirModel* model)
 
     mDateWidget = new DateWidget;
 
-    QHBoxLayout* layout = new QHBoxLayout(this);
+    auto* layout = new QHBoxLayout(this);
     layout->setContentsMargins(0, 0, 0, 0);
     layout->addWidget(mModeComboBox);
     layout->addWidget(mDateWidget);
@@ -140,7 +140,7 @@ RatingFilterWidget::RatingFilterWidget(SortedDirModel* model)
     mRatingWidget->setHalfStepsEnabled(true);
     mRatingWidget->setMaxRating(10);
 
-    QHBoxLayout* layout = new QHBoxLayout(this);
+    auto* layout = new QHBoxLayout(this);
     layout->setContentsMargins(0, 0, 0, 0);
     layout->addWidget(mModeComboBox);
     layout->addWidget(mRatingWidget);
@@ -183,7 +183,7 @@ TagFilterWidget::TagFilterWidget(SortedDirModel* model)
 
     mTagComboBox = new QComboBox;
 
-    QHBoxLayout* layout = new QHBoxLayout(this);
+    auto* layout = new QHBoxLayout(this);
     layout->setContentsMargins(0, 0, 0, 0);
     layout->addWidget(mModeComboBox);
     layout->addWidget(mTagComboBox);
@@ -192,7 +192,7 @@ TagFilterWidget::TagFilterWidget(SortedDirModel* model)
     backEnd->refreshAllTags();
     TagModel* tagModel = TagModel::createAllTagsModel(this, backEnd);
 
-    QCompleter* completer = new QCompleter(mTagComboBox);
+    auto* completer = new QCompleter(mTagComboBox);
     completer->setCaseSensitivity(Qt::CaseInsensitive);
     completer->setModel(tagModel);
     mTagComboBox->setCompleter(completer);
@@ -243,14 +243,14 @@ public:
 
     void setFilterWidget(QWidget* widget)
     {
-        QToolButton* closeButton = new QToolButton;
+        auto* closeButton = new QToolButton;
         closeButton->setIcon(QIcon::fromTheme(QStringLiteral("window-close")));
         closeButton->setAutoRaise(true);
         closeButton->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Minimum);
-        int size = IconSize(KIconLoader::Small);
+        int size = style()->pixelMetric(QStyle::PM_SmallIconSize);
         closeButton->setIconSize(QSize(size, size));
         connect(closeButton, &QAbstractButton::clicked, this, &QObject::deleteLater);
-        QHBoxLayout* layout = new QHBoxLayout(this);
+        auto* layout = new QHBoxLayout(this);
         layout->setContentsMargins(2, 2, 2, 2);
         layout->setSpacing(2);
         layout->addWidget(widget);
@@ -281,7 +281,7 @@ FilterController::FilterController(QFrame* frame, SortedDirModel* dirModel)
     mFilterWidgetCount = 0;
 
     mFrame->hide();
-    FlowLayout* layout = new FlowLayout(mFrame);
+    auto* layout = new FlowLayout(mFrame);
     layout->setSpacing(2);
 
     addAction(i18nc("@action:inmenu", "Filter by Name"),
@@ -341,7 +341,7 @@ void FilterController::slotFilterWidgetClosed()
 
 void FilterController::addAction(const QString& text, const char* slot, const QKeySequence &shortcut)
 {
-    QAction* action = new QAction(text, q);
+    auto* action = new QAction(text, q);
     action->setShortcut(shortcut);
     QObject::connect(action, SIGNAL(triggered()), q, slot);
     mActionList << action;
@@ -353,7 +353,7 @@ void FilterController::addFilter(QWidget* widget)
     if (mFrame->isHidden()) {
         mFrame->show();
     }
-    FilterWidgetContainer* container = new FilterWidgetContainer;
+    auto* container = new FilterWidgetContainer;
     container->setFilterWidget(widget);
     mFrame->layout()->addWidget(container);
 
