@@ -37,6 +37,7 @@ namespace Gwenview
 
 class DocumentView;
 class SlideContainer;
+class BackgroundColorWidget;
 class ZoomWidget;
 
 struct DocumentViewControllerPrivate;
@@ -53,9 +54,11 @@ public:
     ~DocumentViewController() override;
 
     DocumentView* view() const;
+    BackgroundColorWidget* backgroundColorWidget() const;
     ZoomWidget* zoomWidget() const;
 
     void setView(DocumentView*);
+    void setBackgroundColorWidget(BackgroundColorWidget* widget);
     void setZoomWidget(ZoomWidget* widget);
 
     void setToolContainer(SlideContainer* container);
