@@ -24,6 +24,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 // Qt
 #include <QAction>
 #include <QStyleOptionToolButton>
+#include <QStyleOptionToolBar>
 #include <QStylePainter>
 
 // KF
@@ -41,6 +42,40 @@ StatusBarToolButton::StatusBarToolButton(QWidget* parent)
     setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Minimum);
 }
 
+QSize StatusBarToolButton::sizeHint() const
+{
+    QSize sizeHint = QToolButton::sizeHint();
+
+    QStyleOptionToolButton opt;
+    initStyleOption(&opt);
+
+    const bool isIconOnly = opt.toolButtonStyle == Qt::ToolButtonIconOnly
+            || (!opt.icon.isNull() && opt.text.isEmpty());
+    const bool isTextOnly = opt.toolButtonStyle == Qt::ToolButtonTextOnly
+            || (opt.icon.isNull() && !opt.text.isEmpty());
+
+    if (isIconOnly || isTextOnly) {
+        QSize contentSize;
+        if (isIconOnly) {
+            contentSize.setHeight(qMax(opt.iconSize.height(), opt.fontMetrics.height()));
+            contentSize.setWidth(contentSize.height());
+        } else if (isTextOnly) {
+            // copying the default text size behavior for text only QToolButtons
+            QSize textSize = opt.fontMetrics.size(Qt::TextShowMnemonic, opt.text);
+            // NOTE: QToolButton really does use horizontalAdvance() instead of boundingRect().width()
+            textSize.setWidth(textSize.width() + opt.fontMetrics.horizontalAdvance(QLatin1Char(' '))*2);
+            contentSize.setHeight(qMax(opt.iconSize.height(), textSize.height()));
+            contentSize.setWidth(textSize.width());
+        }
+        if (popupMode() == MenuButtonPopup) {
+            contentSize.setWidth(contentSize.width() + style()->pixelMetric(QStyle::PM_MenuButtonIndicator, &opt, this));
+        }
+        sizeHint = style()->sizeFromContents(QStyle::CT_ToolButton, &opt, contentSize, this);
+    }
+
+    return sizeHint;
+}
+
 void StatusBarToolButton::setGroupPosition(StatusBarToolButton::GroupPosition groupPosition)
 {
     mGroupPosition = groupPosition;
@@ -76,17 +111,23 @@ void StatusBarToolButton::paintEvent(QPaintEvent* event)
     painter.drawPrimitive(QStyle::PE_PanelButtonTool, panelOpt);
 
     // Separator
-    const int y1 = opt.rect.top() + 6;
-    const int y2 = opt.rect.bottom() - 6;
+    QStyleOptionToolBar tbOpt;
+    tbOpt.palette = opt.palette;
+    tbOpt.state = QStyle::State_Horizontal;
+    const int width = style()->pixelMetric(QStyle::PM_ToolBarSeparatorExtent);
+    const int height = opt.rect.height() - 2;
+    const int y = opt.rect.y() + (opt.rect.height() - height) / 2;
     if (mGroupPosition & GroupRight) {
-        const int x = opt.rect.left();
-        painter.setPen(opt.palette.color(QPalette::Light));
-        painter.drawLine(x, y1, x, y2);
+        // Kinda hacky. This is needed because of the way toolbar separators are horizontally aligned.
+        // Tested with Breeze (width: 8), Fusion (width: 6) and Oxygen (width: 8)
+        const int x = opt.rect.left() - width/1.5;
+        tbOpt.rect = QRect(x,y,width,height);
+        painter.drawPrimitive(QStyle::PE_IndicatorToolBarSeparator, tbOpt);
     }
     if (mGroupPosition & GroupLeft) {
-        const int x = opt.rect.right();
-        painter.setPen(opt.palette.color(QPalette::Mid));
-        painter.drawLine(x, y1, x, y2);
+        const int x = opt.rect.right() - width/2;
+        tbOpt.rect = QRect(x,y,width,height);
+        painter.drawPrimitive(QStyle::PE_IndicatorToolBarSeparator, tbOpt);
     }
 
     // Text
