@@ -48,19 +48,17 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include "gvbrowserextension.h"
 #include "gvpart.h"
 
-//Factory Code
-K_PLUGIN_FACTORY_WITH_JSON(GVPartFactory, "gvpart.json", registerPlugin<Gwenview::GVPart>();)
-
 namespace Gwenview
 {
 
-GVPart::GVPart(QWidget* parentWidget, QObject* parent, const QVariantList& /*args*/)
+K_PLUGIN_CLASS_WITH_JSON(GVPart, "gvpart.json")
+
+GVPart::GVPart(QWidget* parentWidget, QObject* parent, const KPluginMetaData &metaData, const QVariantList& /*args*/)
 : KParts::ReadOnlyPart(parent)
 {
-    QScopedPointer<KAboutData> aboutData(createAboutData());
-    setComponentData(*aboutData, false);
+    setMetaData(metaData);
 
-    DocumentViewContainer* container = new DocumentViewContainer(parentWidget);
+    auto* container = new DocumentViewContainer(parentWidget);
     setWidget(container);
     mDocumentView = container->createView();
 
@@ -73,10 +71,10 @@ GVPart::GVPart(QWidget* parentWidget, QObject* parent, const QVariantList& /*arg
             this, &GVPart::showContextMenu);
 
     // Necessary to have zoom actions
-    DocumentViewController* documentViewController = new DocumentViewController(actionCollection(), this);
+    auto* documentViewController = new DocumentViewController(actionCollection(), this);
     documentViewController->setView(mDocumentView);
 
-    QAction * action = new QAction(actionCollection());
+    auto * action = new QAction(actionCollection());
     action->setText(i18nc("@action", "Properties"));
     action->setShortcut(QKeySequence(Qt::ALT | Qt::Key_Return));
     connect(action, &QAction::triggered, this, &GVPart::showProperties);
@@ -117,16 +115,6 @@ bool GVPart::openUrl(const QUrl& url)
     return true;
 }
 
-KAboutData* GVPart::createAboutData()
-{
-    KAboutData* aboutData = Gwenview::createAboutData(
-        QStringLiteral("gvpart"), /* appname */
-        i18n("Gwenview KPart")    /* programName */
-        );
-    aboutData->setShortDescription(i18n("An Image Viewer"));
-    return aboutData;
-}
-
 inline void addActionToMenu(QMenu* menu, KActionCollection* actionCollection, const char* name)
 {
     QAction* action = actionCollection->action(name);
